#!C:\bld\mayavi_1504645064423\_b_env\pythonw.exe
# EASY-INSTALL-ENTRY-SCRIPT: 'mayavi==4.5.0','gui_scripts','tvtk_doc'
__requires__ = 'mayavi==4.5.0'
import re
import sys
from pkg_resources import load_entry_point

if __name__ == '__main__':
    sys.argv[0] = re.sub(r'(-script\.pyw?|\.exe)?$', '', sys.argv[0])
    sys.exit(
        load_entry_point('mayavi==4.5.0', 'gui_scripts', 'tvtk_doc')()
    )
